@@ -23,4 +23,4 @@
  "tl-sys:core;loader-funcs" ; reader macro for Clisp to read TL code
  "tl-sys:core;reader-tl-macro" ; TL's pack definition
  "tl-sys:core;tl-def"))
-(tl-for (logPathStr comPathList) (cl:nil) (compile-file (namestring (translate-logical-pathname (logical-pathname logPathStr)))))
+(tl:tl-for (logPathStr comPathList) (cl:nil) (compile-file (namestring (translate-logical-pathname (logical-pathname logPathStr)))))
