@@ -16,7 +16,7 @@
 ;    You should have received a copy of the GNU General Public License
 ;    along with TwinLisp; if not, write to the Free Software
 ;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-(_<<_ (_<<_ (_<<_ (_<<_ (cout) "TwinLisp interpreter.") #\Newline) "Typing \"Ctrl-D\" or \"exit\" quits interpreter.") #\Newline)
+(tl:_<<_ (tl:_<<_ (tl:_<<_ (tl:_<<_ (cout) "TwinLisp interpreter.") #\Newline) "Typing \"Ctrl-D\" or \"exit\" quits interpreter.") #\Newline)
 (var *tl-level-info* (TWINLISP::makeLevelInfo :implScope cl:t :explScopeWarn cl:t))
 ; &*print-circle* = t  ; so that our printer does not choke on circles
-(cl:catch :exit (cl:do (+ ++ +++ - * ** ***) (cl:nil) (cl:handler-case (cl:progn (cl:setf - (read-from-string (translate *tl-level-info* (new TWINLISP::ReaderWriter :firstPrompt ">>> " :secondPrompt "... ") cl:t "exit"))) (cl:setf *** (multiple-value-list (eval -))) (_<<_ (cout) #\Newline) (write (car ***)) (cl:cond ((_>_ (len ***) 1) (tl-for (value (cdr ***)) (cl:nil) (_<<_ (_<<_ (cout) "  ;") #\Newline) (write value)))) (_<<_ (cout) #\Newline)) (error (er) (_<<_ (cout) (_%_ "ERROR: ~A~%" er)) (cl:setf *** (cl:list er)))) (cl:setf +++ (car ***)) (cl:setf *** **) (cl:setf ** *) (cl:setf * +++) (cl:setf +++ ++) (cl:setf ++ +) (cl:setf + -)))
+(cl:catch :exit (cl:do (+ ++ +++ - * ** ***) (cl:nil) (cl:handler-case (cl:progn (cl:setf - (read-from-string (translate *tl-level-info* (new TWINLISP::ReaderWriter :firstPrompt ">>> " :secondPrompt "... ") cl:t "exit"))) (cl:setf *** (multiple-value-list (eval -))) (tl:_<<_ (cout) #\Newline) (write (car ***)) (cl:cond ((tl:_>_ (len ***) 1) (tl:tl-for (value (cdr ***)) (cl:nil) (tl:_<<_ (tl:_<<_ (cout) "  ;") #\Newline) (write value)))) (tl:_<<_ (cout) #\Newline)) (error (er) (tl:_<<_ (cout) (tl:_%_ "ERROR: ~A~%" er)) (cl:setf *** (cl:list er)))) (cl:setf +++ (car ***)) (cl:setf *** **) (cl:setf ** *) (cl:setf * +++) (cl:setf +++ ++) (cl:setf ++ +) (cl:setf + -)))
