@@ -20,6 +20,6 @@
 (cl:defgeneric _copy_ (obj) (:documentation "This function is used by copy:copy(). Returns copy of an object.") (:method ((obj bit-vector)) obj) (:method ((obj character)) obj) (:method ((obj number)) obj) (:method ((obj string)) (copy-seq obj)) (:method ((obj symbol)) obj))
 (cl:defgeneric _deepcopy_ (obj memo) (:documentation "This function is used by copy:deepcopy(). Returns a deep copy of an object and an update memo (hash-table with obj->objCopy mapping).") (:method ((obj bit-vector) memo) (cl:values obj memo)) (:method ((obj character) memo) (cl:values obj memo)) (:method ((obj number) memo) (cl:values obj memo)) (:method ((obj string) memo) (cl:values (copy-seq obj) memo)) (:method ((obj symbol) memo) (cl:values obj memo)))
 ;; getting states of objects or structure
-(cl:flet ((slots-values-to-htab (obj) (tl-for (slotDescr (clos:class-slots (class-of obj)) (tab (_make-hash-table_))) (tab) (cl:cond ((slot-boundp obj (cl:slot-value slotDescr 'clos::$name)) (cl:setf (_getitem_ tab (cl:slot-value slotDescr 'clos::$name)) (slot-value obj (cl:slot-value slotDescr 'clos::$name)))))))) (cl:defgeneric _getstate_ (obj) (:method ((obj structure-object)) (slots-values-to-htab obj)) (:method ((obj standard-object)) (slots-values-to-htab obj))))
+(cl:flet ((slots-values-to-htab (obj) (tl:tl-for (slotDescr (clos:class-slots (class-of obj)) (tab (tl:_make-hash-table_))) (tab) (cl:cond ((slot-boundp obj (cl:slot-value slotDescr 'clos::$name)) (cl:setf (tl:_getitem_ tab (cl:slot-value slotDescr 'clos::$name)) (slot-value obj (cl:slot-value slotDescr 'clos::$name)))))))) (cl:defgeneric _getstate_ (obj) (:method ((obj structure-object)) (slots-values-to-htab obj)) (:method ((obj standard-object)) (slots-values-to-htab obj))))
 ;; setting states of objects or structure
 (cl:flet ((set-slots-from-htab (obj state) (maphash #'(cl:lambda (key value) (cl:setf (slot-value obj key) value)) state))) (cl:defgeneric _setstate_ (obj state) (:method ((obj structure-object) state) (set-slots-from-htab obj state)) (:method ((obj standard-object) state) (set-slots-from-htab obj state))))
