@@ -16,7 +16,7 @@
 ;    along with TwinLisp; if not, write to the Free Software
 ;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 (tl-require "unittest")
-(_<<_ (_<<_ (_<<_ (cout) #\Newline) "Testing TwinLisp's core components:") #\Newline)
+(tl:_<<_ (tl:_<<_ (tl:_<<_ (cout) #\Newline) "Testing TwinLisp's core components:") #\Newline)
 ; testcases defined in the current pack
 (tl-require "TestOperMeths")
 (tl-require "TestContainerMeths")
